
<div class="row">
	<br/>
	<div class="col-xs-4">
		<small>
			<i class="fa fa-fw fa-calendar-o"></i>
			<span class="non-mobile-only"> 
				{{event.start_time | date:"D"}} 
			</span>
			{{event.start_time | date:"m/d"}}
			
			<span class="non-mobile-only">
				<i class="fa fa-fw fa-clock-o"></i> 
			</span>
			{{event.start_time| date:"g:ia"}}<br/>
			<span class="desktop-only text-muted">
				{{event.location_name}}<br />
			</span>
		</small>
	</div>
	<div class="col-xs-8">
		<p>
			{{ event.link_html | safe }}<br/>
			<span class="small text-muted">{{event.description}}</span>
		</p>
	</div>
</div>