{% load extras %}
<p class="small text-muted no-pad-bottom">
    <span class="text-muted"><i class="fa fa-fw fa-check"></i> Passed on {{legislation.date_passed|date:'n/d'}}</span><br />
    <a href="/legislation/{{ legislation.slug }}/">{{ legislation.friendly_name }}</a>
</p>
<div class='row'>
    <div class='col-xs-11'>
        <p>
            {{ legislation.listing_description | short_blurb }}.
        </p>

    </div>
    <div class='col-xs-1 no-pad-mobile'>
        <div>
            <a class='btn-bill-detail' href='/legislation/{{ legislation.slug }}/'>
                <i class="fa fa-fw fa-chevron-right"></i>
            </a>
        </div>
    </div>
</div>
<p>
    {% if legislation.topics %}
        <i class="fa fa-fw fa-tag"></i>
        {% for tag in legislation.topics %}
            <span class="badge badge-muted pseudo-topic-tag">
                <a href='/search/?q=&selected_facets=topics_exact:{{ tag }}'>{{ tag }}</a>
            </span>&nbsp;
        {% endfor %}
    {% else %}
        <i class="fa fa-fw fa-tag"></i>
        {% for tag in legislation.pseudo_topics %}
            <span class="badge badge-muted pseudo-topic-tag">
                <a href='/search/?q=&selected_facets=topics_exact:{{ tag | committee_topic_only }}'>{{ tag | committee_topic_only }}</a>
            </span>&nbsp;
        {% endfor %}
    {% endif %}
    <br/><br/>
</p>
